@@ -13,6 +13,7 @@
 
 #include <QDialog>
 #include <QDialogButtonBox>
+#include <memory>
 
 #include <kwidgetsaddons_export.h>
 
@@ -26,10 +27,11 @@
  * Requesting a simple password, asynchronous
  *
  * \code
- *  KPasswordDialog *dlg = new KPasswordDialog( parent );
+ *  KPasswordDialog *dlg = new KPasswordDialog(parent);
  *  dlg->setPrompt(i18n("Enter a password"));
- *  connect( dlg, SIGNAL( gotPassword( const QString& , bool ) )  , this, SLOT( setPassword( const QString &) ) );
- *  connect( dlg, SIGNAL( rejected() )  , this, SLOT( slotCancel() ) );
+ *  connect(dlg, &KPasswordDialog::gotPassword,
+ *          this, [this](const QString &password) { setPassword(password); });
+ *  connect(dlg, &QDialog::rejected, this, [this]() { slotCancel(); });
  *  dlg->show();
  * \endcode
  *
@@ -38,9 +40,10 @@
  * \code
  *  KPasswordDialog dlg(parent, KPasswordDialog::ShowUsernameLine);
  *  dlg.setPrompt(i18n("Enter a login and a password"));
- *  if( !dlg.exec() )
+ *  if(!dlg.exec()) {
  *      return; //the user canceled
- *  use( dlg.username() , dlg.password() );
+ *  }
+ *  use(dlg.username(), dlg.password());
  * \endcode
  *
  * \image html kpassworddialog.png "KPasswordDialog"
@@ -52,7 +55,6 @@ class KWIDGETSADDONS_EXPORT KPasswordDialog : public QDialog
     Q_OBJECT
 
 public:
-
     /**
      * @see KPasswordDialogFlags
      */
@@ -86,7 +88,7 @@ public:
          * If this flag is set, the domain lineedit will be in read only mode.
          * @since 4.1
          */
-        DomainReadOnly = 0x20
+        DomainReadOnly = 0x20,
     };
     /**
      * Stores a combination of #KPasswordDialogFlag values.
@@ -115,7 +117,7 @@ public:
          * A problem with the domain as entered
          * @since 4.1
          */
-        DomainError
+        DomainError,
     };
 
     /**
@@ -124,8 +126,7 @@ public:
      * @param parent the parent widget
      * @param flags a set of KPasswordDialogFlag flags
      */
-    explicit KPasswordDialog(QWidget *parent = nullptr,
-                             const KPasswordDialogFlags &flags = KPasswordDialog::NoFlags);
+    explicit KPasswordDialog(QWidget *parent = nullptr, const KPasswordDialogFlags &flags = KPasswordDialog::NoFlags);
 
     /**
      * Destructor
@@ -302,6 +303,23 @@ public:
      */
     void setUsernameContextHelp(const QString &help);
 
+    /**
+     * Whether to show the visibility trailing action in the line edit.
+     * Default is @c true. This can be used to honor the lineedit_reveal_password
+     * kiosk key, for example:
+     * \code
+     * dlg->setRevealPasswordAvailable(KAuthorized::authorize(QStringLiteral("lineedit_reveal_password")));
+     * \endcode
+     * @since 5.84
+     */
+    void setRevealPasswordAvailable(bool reveal);
+
+    /**
+     * Whether the visibility trailing action in the line edit is visible.
+     * @since 5.84
+     */
+    bool isRevealPasswordAvailable() const;
+
 Q_SIGNALS:
     /**
      * emitted when the dialog has been accepted
@@ -327,14 +345,8 @@ protected:
     virtual bool checkPassword();
 
 private:
-    Q_PRIVATE_SLOT(d, void actuallyAccept())
-    Q_PRIVATE_SLOT(d, void activated(const QString &userName))
-    Q_PRIVATE_SLOT(d, void updateFields())
-
-private:
-    class KPasswordDialogPrivate;
     friend class KPasswordDialogPrivate;
-    KPasswordDialogPrivate *const d;
+    std::unique_ptr<class KPasswordDialogPrivate> const d;
 
     Q_DISABLE_COPY(KPasswordDialog)
 };
